#!/bin/bash

# Check if the filename was provided as an argument
if [ $# -eq 0 ]; then
  echo "Usage: $0 database_dump.gz"
  exit 1
fi

# Get the filename and extension
filename="$1"
new_filename="${filename%.gz}"
extension="${filename##*.}"

# Check if the file exists and is gzipped
if [ ! -f $filename ]; then
  echo "File $filename not found."
elif [ $extension != "gz" ]; then
  echo "File $filename is not gzipped."
  exit 1
fi

# Check if the output file already exists
if [ -f $new_filename ]; then
  echo "Output file $new_filename already exists. Skipping gunzip."
else
  # Gunzip the file
  gunzip -c $filename > $new_filename

  # Check if gunzip was successful
  if [ $? -eq 0 ]; then
    echo "Gunzip successful. New filename: $new_filename"
  else
    echo "Gunzip failed."
    exit 1
  fi
fi

# Copy into containers mapped folder
cp "$new_filename" "database/$new_filename"

# Stop server
echo "Stopping server to perform migration"
./stop.sh

# Start just db container
echo "Starting db container"
docker compose -p xenia-server start db

# Perform a backup of the current db as a precaution
./backup_db.sh

# Perform update
docker compose -p xenia-server exec -T db psql -f "/docker-entrypoint-initdb.d/$new_filename"

# Grant permission for older dbs
docker compose -p xenia-server exec -T db psql -U root xenia --command "GRANT ALL ON SCHEMA public TO docker;"

# Start server again
./run.sh

exit 0
